#
# BEGIN COPYRIGHT
# *************************************************************************
# Licensed Materials - Property of IBM 
# 5724-L01, 5655-N53, 5724-I82, 5655-R15
# (C) Copyright IBM Corporation 2006. All rights reserved. 
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# *************************************************************************
# END COPYRIGHT

#  
# The sample contained herein is provided to you "AS IS".
# It is furnished by IBM as a sample script


from java.io import FileInputStream, IOException
from java.util import Properties
from os.path import abspath, normpath, exists
import os
import sys
import java.lang.System

errorCode = ""
errorInfo = ""

#
#   The following function:  modSpecialEndpoint, requires thrww parameters or arguments, specialEndpoint, 
#   endpointName, and endpointPort.  It modifies the existing value for the port.  It returns nothing.
def modSpecialEndpoint(specialEndpoint, endpointName, endpointPort):
        epoint = AdminConfig.showAttribute(specialEndpoint, 'endPoint')
        hostn = AdminConfig.showAttribute(epoint, hostc)
        portorig = AdminConfig.showAttribute(epoint, portc)
        if (int(portorig) != endpointPort) :
          AdminConfig.modify(epoint, [[portc, endpointPort]])
          portn = AdminConfig.showAttribute(epoint, portc)
          print "Updating " + endpointName,
          print " from :",
          print portorig,
          print " to ",
          print portn
        #endIf 
        return
#endDef

#
#
#   The following function:  modNamedEndpoint, requires three parameters or arguments, namedEndpoint, 
#   endpointName, and endpointPort.  It modifies the existing value for the port.  It returns nothing.
def modNamedEndpoint(namedEndpoint, endpointName, endpointPort):
        hostn = AdminConfig.showAttribute(namedEndpoint, hostc)
        portorig = AdminConfig.showAttribute(namedEndpoint, portc)
        if (int(portorig) != endpointPort) :
          AdminConfig.modify(namedEndpoint, [[portc, endpointPort]])
          portn = AdminConfig.showAttribute(namedEndpoint, portc)
          print "Updating " + endpointName,
          print " from :",
          print portorig,
          print " to ",
          print portn
        #endIf 
        return
#endDef


#*******************************************************************************************************
# Procedure to Set Port Assignments
#*******************************************************************************************************

def assignPorts(orgport, s1, n1 ,c1 ):

    orgport = int(orgport)
    s1template = '/Cell:'
    s1template = s1template + c1
    s1template = s1template + '/Node:'
    s1template = s1template + n1
    s1template = s1template + '/Server:'
    s1template = s1template + s1
    s1template = s1template + '/'
    s1id = AdminConfig.getid(s1template)


#
#   The orgport variable should be set to the lowest port number for the server, usually the
#   port for the soap address.
#
#   The manipulation of the port number here is done based on the port scheme for a server as done
#   in the spreadsheet which can be found on the techdocs website:  http://www.ibm.com/support/techdocs
#   as Techdoc # is WP101953 for V7.5 of WBPM on z/OS
#
    bootstrapportname = 'BOOTSTRAP_ADDRESS'
    bootstrapportnumber = orgport + 3
    dcsportname = 'DCS_UNICAST_ADDRESS'
    dcsportnumber = orgport + 10
    ipcportname = 'IPC_CONNECTOR_ADDRESS'
    ipcportnumber = orgport + 9
    orbportname = 'ORB_LISTENER_ADDRESS'
    orbportnumber = orgport + 3
    orbsslportname = 'ORB_SSL_LISTENER_ADDRESS'
    orbsslportnumber = orgport + 4
    sibportname = 'SIB_ENDPOINT_ADDRESS'
    sibportnumber = orgport + 11
    sibsslportname = 'SIB_ENDPOINT_SECURE_ADDRESS'
    sibsslportnumber = orgport + 12
    sibmqportname = 'SIB_MQ_ENDPOINT_ADDRESS'
    sibmqportnumber = orgport + 13
    sibmqsslportname = 'SIB_MQ_ENDPOINT_SECURE_ADDRESS'
    sibmqsslportnumber = orgport + 14
    sipportname = 'SIP_DEFAULTHOST'
    sipportnumber = orgport + 15
    sipsslportname = 'SIP_DEFAULTHOST_SECURE'
    sipsslportnumber = orgport + 16
    soapportname = 'SOAP_CONNECTOR_ADDRESS'
    soapportnumber = orgport + 2
    wcadminportname = 'WC_adminhost'
    wcadminportnumber = orgport + 5
    wcadminsslportname = 'WC_adminhost_secure'
    wcadminsslportnumber = orgport + 6
    wcdefaultportname = 'WC_defaulthost'
    wcdefaultportnumber = orgport + 7
    wcdefaultsslportname = 'WC_defaulthost_secure'
    wcdefaultsslportnumber = orgport + 8
    overlayudpportname = 'OVERLAY_UDP_LISTENER_ADDRESS'
    overlayudpportnumber = orgport + 18
    overlaytcpportname = 'OVERLAY_TCP_LISTENER_ADDRESS'
    overlaytcpportnumber = orgport + 19
#
#  start to modify the ports
#
#
#  set up needed constants
#
#
#  Modify the soap port
#
    soap = AdminConfig.list('SOAPConnector', s1id)
    sca = AdminConfig.showAttribute(soap, soapportname)
    modNamedEndpoint(sca, soapportname, soapportnumber)
#
#  Modify the bootstrap port
#
    boot = AdminConfig.list('NameServer', s1id)
    sca = AdminConfig.showAttribute(boot, bootstrapportname)
    modNamedEndpoint(sca, bootstrapportname, bootstrapportnumber)
#
#  Modify the jms queued and direct ports if they exist
#
    jms = AdminConfig.list('JMSServer', s1id)
    if jms <> "":
      jmsqca = AdminConfig.showAttribute(jms, jmsqueuedportname)
      modNamedEndpoint(jmsqca, jmsqueuedportname, jmsqueuedportnumber)
      jmsdca = AdminConfig.showAttribute(jms, jmsdirectportname)
      modNamedEndpoint(jmsdca, jmsdirectportname, jmsdirectportnumber)
    else:
      print "No JMS Server to modify"
    #endIf
#
#  Modify the "special endpoint" ports
#
#
#  set up node name plist for getid
#
    n1template = '/Node:'
    n1template = n1template + n1
    n1template = n1template + '/'
    node = AdminConfig.getid(n1template)
    serverentries = AdminConfig.list('ServerEntry', node).split(nl)
    for se in serverentries:
       sename = AdminConfig.showAttribute(se, 'serverName')
       if (sename == s1):
         sepstring = AdminConfig.showAttribute(se, 'specialEndpoints')
         seplist = sepstring[1:len(sepstring)-1].split(" ")
    	 for sepe in seplist:
            epname = AdminConfig.showAttribute(sepe, 'endPointName')
            if epname == orbportname:
              modSpecialEndpoint(sepe, orbportname, orbportnumber)
            elif epname == orbsslportname:
              modSpecialEndpoint(sepe, orbsslportname, orbsslportnumber)
            elif epname == dcsportname:
              modSpecialEndpoint(sepe, dcsportname, dcsportnumber)
            elif epname == ipcportname:
                modSpecialEndpoint(sepe, ipcportname, ipcportnumber)
            elif epname == wcdefaultportname:
              modSpecialEndpoint(sepe, wcdefaultportname, wcdefaultportnumber)
            elif epname == wcdefaultsslportname:
              modSpecialEndpoint(sepe, wcdefaultsslportname, wcdefaultsslportnumber)
            elif epname == wcadminportname:
              modSpecialEndpoint(sepe, wcadminportname, wcadminportnumber)
            elif epname == wcadminsslportname:
              modSpecialEndpoint(sepe, wcadminsslportname, wcadminsslportnumber)
            elif epname == sibportname:
              modSpecialEndpoint(sepe, sibportname, sibportnumber)
            elif epname == sibsslportname:
              modSpecialEndpoint(sepe, sibsslportname, sibsslportnumber)
            elif epname == sipportname:
              modSpecialEndpoint(sepe, sipportname, sipportnumber)
            elif epname == sipsslportname:
              modSpecialEndpoint(sepe, sipsslportname, sipsslportnumber)
            elif epname == sibmqportname:
              modSpecialEndpoint(sepe, sibmqportname, sibmqportnumber)
            elif epname == sibmqsslportname:
              modSpecialEndpoint(sepe, sibmqsslportname, sibmqsslportnumber)
            #endif

#
#  Now add the new http and https ports as host aliases for the default_host virtual host
#
    wcdefsw = 'y'
    wcdefsslsw = 'y'
    wcadmsw = 'y'
    wcadmsslsw = 'y'

    vhlist = AdminConfig.list("VirtualHost").split(nl)
    for vh in vhlist:
       if AdminConfig.showAttribute(vh, 'name') == 'default_host':
         vhaliaslist = AdminConfig.list("HostAlias", vh).split(nl)
         for vha in vhaliaslist: 
            if int(AdminConfig.showAttribute(vha, portc)) == wcdefaultportnumber:
              wcdefsw = 'n'
            elif int(AdminConfig.showAttribute(vha, portc)) == wcdefaultsslportnumber:
              wcdefsslsw = 'n'
         if wcdefsw == 'y':
           AdminConfig.create('HostAlias', vh, [[vhhostc, '*'], [portc, wcdefaultportnumber]])
           print "Adding Host Alias entry for port number ",
           print wcdefaultportnumber
         if wcdefsslsw == 'y':
           AdminConfig.create('HostAlias', vh, [[vhhostc, '*'], [portc, wcdefaultsslportnumber]])
           print "Adding Host Alias entry for port number ",
           print wcdefaultsslportnumber
       elif AdminConfig.showAttribute(vh, 'name') == 'admin_host':
         vhaliaslist = AdminConfig.list("HostAlias", vh).split(nl)
         for vha in vhaliaslist:
            if int(AdminConfig.showAttribute(vha, portc)) == wcadminportnumber:
              wcadmsw = 'n'
            elif int(AdminConfig.showAttribute(vha, portc)) == wcadminsslportnumber:
              wcadmsslsw = 'n'
         if wcadmsw == 'y':
           AdminConfig.create('HostAlias', vh, [[vhhostc, '*'], [portc, wcadminportnumber]])
           print "Adding Host Alias entry for port number ",
           print wcadminportnumber
         if wcadmsslsw == 'y':
           AdminConfig.create('HostAlias', vh, [[vhhostc, '*'], [portc, wcadminsslportnumber]])
           print "Adding Host Alias entry for port number ",
           print wcadminsslportnumber

    return 0

#endDef

#*******************************************************************************************************
# Procedure to Obtain Topic Connection factory
#*******************************************************************************************************

def updateEndpoints( c1, n1, s1):

  if (clusterName != "") :
    clusterScope="/ServerCluster:"+clusterName+"/"
    scope=AdminConfig.getid(clusterScope)
  else :
    serverScope ="/Cell:"+cellName+"+/Node:"+nodeName+"/Server:"+serverName+"/"
    scope=AdminConfig.getid(serverScope)
  #endIf


  tcflist = AdminTask.listSIBJMSConnectionFactories(scope,'-type topic')
  tcflist = tcflist.split(java.lang.System.getProperty("line.separator"))

  sibportname    = 'SIB_ENDPOINT_ADDRESS'  
  sibsslportname = 'SIB_ENDPOINT_SECURE_ADDRESS'

  port  = getPortByName(c1, n1, s1, sibportname)
  sport = getPortByName(c1, n1, s1, sibsslportname)

  host  = getHostName(c1, n1, s1)

  for tcf in tcflist:
       updateEndpointProperty(tcf,host,port,sport)
  #endFor    

  serverScope ="/Node:"+n1+"/Server:"+s1+"/"

  http  = getPortByName(c1, n1, s1, 'WC_defaulthost' )
  updateProperty( 'teamworks.tester.appServerPort' , http ,serverScope)
  return 0

#endDef

#*******************************************************************************************************
# Procedure to Obtain EndpointProperty  ProviderEndpoints
#*******************************************************************************************************

def updateEndpointProperty( tcf, host, port, sport ):

  nameTCF=AdminConfig.showAttribute(tcf, "name")
  boot =host+":"+port+":BootstrapBasicMessaging"
  sboot=host+":"+sport+":BootstrapSecureMessaging"

  propertySet= AdminConfig.showAttribute(tcf,"propertySet")
  properties = AdminConfig.showAttribute(propertySet, "resourceProperties" )
  properties = properties.split(" ")

  for property in properties:
       name=AdminConfig.showAttribute(property, "name")
       if (name == "ProviderEndpoints") :
            inValue =AdminConfig.showAttribute(property, "value")
#79283 - All Bus's are currently Secure
            value = sboot 
            if (value != inValue ) : 
               valAttr = ["value", value]
               propAttr = [valAttr]
               AdminConfig.modify(property, propAttr )
               print "Updating ProviderEndpoints " + nameTCF + java.lang.System.getProperty("line.separator") + value   
            #endIf
            break
       #endIf
  #endFor    

  return 0

#endDef

#*******************************************************************************************************
# Procedure to Set Port Assignments
#*******************************************************************************************************

def getHostName( c1, n1, s1 ):

  bootstrapname = 'BOOTSTRAP_ADDRESS'
  s1template = '/Cell:'
  s1template = s1template + c1
  s1template = s1template + '/Node:'
  s1template = s1template + n1
  s1template = s1template + '/Server:'
  s1template = s1template + s1
  s1template = s1template + '/'
  s1id = AdminConfig.getid(s1template)
#
  boot  = AdminConfig.list('NameServer', s1id)
  sca   = AdminConfig.showAttribute(boot, bootstrapname)
  hostn = AdminConfig.showAttribute(sca, hostc)

  return hostn

#endDef

#*******************************************************************************************************
# Procedure to Get BootstrapPort
#*******************************************************************************************************

def getBootPort( c1, n1, s1 ):

  bootstrapname = 'BOOTSTRAP_ADDRESS'
  s1template = '/Cell:'
  s1template = s1template + c1
  s1template = s1template + '/Node:'
  s1template = s1template + n1
  s1template = s1template + '/Server:'
  s1template = s1template + s1
  s1template = s1template + '/'
  s1id = AdminConfig.getid(s1template)

#
  boot     = AdminConfig.list('NameServer', s1id)
  sca      = AdminConfig.showAttribute(boot, bootstrapname)
  portorig = AdminConfig.showAttribute(sca, portc)

  return portorig

#endDef


#*******************************************************************************************************
# Procedure to Get Port
#*******************************************************************************************************

def getPortByName(c1, n1, s1, portName ):
  s1template = '/Cell:'
  s1template = s1template + c1
  s1template = s1template + '/Node:'
  s1template = s1template + n1
  s1template = s1template + '/Server:'
  s1template = s1template + s1
  s1template = s1template + '/'
  s1id = AdminConfig.getid(s1template)
  n1template = '/Node:'
  n1template = n1template + n1
  n1template = n1template + '/'
  node = AdminConfig.getid(n1template)
  serverentries = AdminConfig.list('ServerEntry', node).split(nl)
  for se in serverentries:
     sename = AdminConfig.showAttribute(se, 'serverName')
     if (sename == s1):
       sepstring = AdminConfig.showAttribute(se, 'specialEndpoints')
       seplist = sepstring[1:len(sepstring)-1].split(" ")
       for sepe in seplist:
          epname = AdminConfig.showAttribute(sepe, 'endPointName')
          if epname == portName:
            epoint = AdminConfig.showAttribute(sepe, 'endPoint')
            portorig = AdminConfig.showAttribute(epoint, portc)
          #endif

  return portorig

#endDef

#
#*******************************************************************************************************
# Procedure to validate Property Exists   
#*******************************************************************************************************
def updateProperty ( inPropertyName, inPropertyValue, inScope ):

        property  = 'IBM_JAVA_OPTIONS'
        propName  = inPropertyName
        propValue = inPropertyValue
        scope     = inScope

        nodeVarMapList = AdminConfig.getid(scope )

        if (len(nodeVarMapList) == 0):
                print "No VariableMap found for "+`scope`
                return 
        #endIf 

        for var in AdminConfig.list("VariableSubstitutionEntry", nodeVarMapList ).split(nl):
                symbolicName = AdminConfig.showAttribute(var, "symbolicName" )
                if (symbolicName == property):
                        origValue = AdminConfig.showAttribute(var, "value" )
                        jvmargs = origValue.split("-D")
                        for arg in jvmargs:
                           if (arg!=" " and arg!="" ):
                              prop=arg.split("=")
                              pval=prop[1].strip()
                              if(prop[0]==propName and pval == propValue):
                                 return 0
                              elif(prop[0]==propName and prop[1] != propValue):
                                  strNew = propName+"="+propValue + " "
                                  newValue = origValue.replace(arg,strNew) 
                                  valAttr = ["value", newValue]
                                  propAttr = [valAttr]
                                  AdminConfig.modify(var, propAttr )
                                  print "--------------------------------------------------------------------------"
                                  print "Updating IBM_JAVA_OPTIONS: "+propName + "   from " + prop[1] +" to " + propValue
                                  return 0
                              #endIf  
                        #endFor   
                        #return 0
                #endIf 
        #endFor 

        return 0
#endDef 

#
#*******************************************************************************************************
# Procedure to delete Property
#*******************************************************************************************************
def deleteProperty ( inPropertyName,inScope ):

        property  = inPropertyName
        scope     = inScope

        nodeVarMapList = AdminConfig.getid(scope)

        if (len(nodeVarMapList) == 0):
                print "No VariableMap found for "+`scope`
                return 
        #endIf 

        for var in AdminConfig.list("VariableSubstitutionEntry", nodeVarMapList ).split(nl):
                symbolicName = AdminConfig.showAttribute(var, "symbolicName" )
                if (symbolicName == property):
                        AdminConfig.remove(var)
                        print "--------------------------------------------------------------------------"
                        print "Removing Variable: "+property + " from Scope: " + scope
                        return 0
                #endIf 
        #endFor 

        return 0
#endDef 


#*******************************************************************************************************
# Procedure to Update WLE RestService
#*******************************************************************************************************

def updateRESTEndpoint(cluster, httpPort, httpsPort ):
   # Only Update the Endpoints for the Cluster
   id="cells:"+cellName+":clusters:"+cluster
   
   for target in AdminConfig.list("WBIRestDeploymentTarget").split(nl):
      clusterId    = AdminConfig.showAttribute(target, "contextID" )
      if ( clusterId == id) :
        for var in AdminConfig.list("WBIRestWebModule",target).split(nl):
           name    = AdminConfig.showAttribute(var, "name" )
           type    = AdminConfig.showAttribute(var, "transportType" )
           appName = AdminConfig.showAttribute(var, "applicationName" )
           port    = AdminConfig.showAttribute(var, "port" )
           if ( type == "https://" ) :
             newPort = httpsPort
           else :
             newPort = httpPort
           #endIf 
           if ( port != newPort):
             AdminTask.updateRESTServiceProvider(['-clusterName', cluster , '-appName', appName, '-webModuleName', name, '-port', newPort])
             print "Updating Endpoint port: "+ name + " to " + newPort 
           #endIf 
        #endFor 
      #endIf
   #endFor
   print "--------------------------------------------------------------------------"
   return 0

#endDef 

#*******************************************************************************************************
# Procedure to Update WLE Configuration files
#*******************************************************************************************************

def updateConfiguration( cellname, nodename, server, cluster , inparms ):


  host         = getHostName(cellname, nodename, server) 
  boot         = getBootPort(cellname, nodename, server) 
  http         = getPortByName(cellname, nodename, server, 'WC_defaulthost' ) 
  https        = getPortByName(cellname, nodename, server, 'WC_defaulthost_secure' ) 
#74198 - Designer currently requires corbaloc
  bootstrapurl = "corbaloc:iiop:"+host+":"+boot
 
  if (cluster != "") :
    parms =  '-clusterName ' + cluster
    updateRESTEndpoint(cluster, http, https)
  else :
    parms =  '-nodeName ' + nodename + ' -serverName ' + server

  if (ports != "") :
    parms = parms + ' -appServerName ' + host + ' -appServerPort ' + http + ' -bootstrapURL ' + bootstrapurl
  elif (inparms == "") :
    print "No BPMConfig Updates"
    return 0

  parms = parms + inparms
  print "UpdateBPMConfig Parameters:"
  print parms
   
  AdminTask.updateBPMConfig(parms)

  return 0

#endDef




#*******************************************************************************************************
# Procedure to Obtain EndpointProperty  ProviderEndpoints
#*******************************************************************************************************

def syncNodes():

  nl = AdminConfig.list('Node').split(nl)
  for n in nl:
     nn = AdminConfig.showAttribute(n, 'name')
     objn = "type=NodeSync,node=" + nn + ",*"
     Syncl = AdminControl.completeObjectName(objn)
     if Syncl != "":
         AdminControl.invoke(Syncl, 'sync')
         print "Done with node " + nn
     else:
         print "Skipping node " + nn
     continue

#endDef

#*******************************************************************************************************
# MAIN
#*******************************************************************************************************

#
# Commandline parameter handling
#
#99LocalFlags
flags="-environmentName,-appServerName,-appServerPort,-adminID,-adminPassword,-authorID,-authorPassword,-serverID,-serverPassword,-repositoryServerURL,-repositoryServerHeartbeat,-bootstrapUrl,-operatorID"
#98Database.xml
flags=flags+",-procsrvDBURL,-perfDWDBURL,-procsrvDBUserID,-procsrvDBPassword,-perfDWDBUserID,-perfDWDBPassword,-performanceDWJNDIURL,-performanceDWScope"
#Turn to List Format
flags=flags.split(",")


ports	          = ""
serverName      = ""          
nodeName        = ""          
clusterName     = ""   


parameters      = ""         # Collection of updateConfiguration parameters

cellName        = java.lang.System.getProperty ( "local.cell" )
hostc           = 'host'
portc           = 'port'
vhhostc         = 'hostname'

nl              = java.lang.System.getProperty("line.separator")

argc            = len(sys.argv)
display         = 0
sync            = 0
help            = 0


i = 0  #forStart
while ( i < argc ):  #forTest
        arg = sys.argv[i]
        found = 0
#-------------------------------------------------------------------------------------------------------------------------------
#Flags List is used for parameter(s) input to AdminTask.updateBPMConfig(parms)
#-------------------------------------------------------------------------------------------------------------------------------
        for flag in flags:
           if (flag == arg):
                found = 1 
                i = i+1;  
                if (i < argc):

                        parameters = parameters + " " + arg + " " + sys.argv[i]
						
                else:
                        argerr = "Missing argument for '" + arg + "' parameter"
                break 
                #endIf
           continue  
           #endIf
        #endFor
        if (found == 1) :
            found = 0
#-------------------------------------------------------------------------------------------------------------------------------
        elif (arg == "-server"):
                i = i+1; 
                if (i < argc):
                        serverName = sys.argv[i]
                else:
                        argerr = "Missing argument for '" + arg + "' parameter"
                #endElse 
        elif (arg == "-ports"):
                i = i+1; 
                if (i < argc):
                        ports = sys.argv[i]
                else:
                        argerr = "Missing argument for '" + arg + "' parameter"
                #endElse 
        elif (arg == "-node"):
                i = i+1; 
                if (i < argc):
                        nodeName = sys.argv[i]
                else:
                        argerr = "Missing argument for '" + arg + "' parameter"
                #endElse 
        elif (arg == "-cluster"):
                i = i+1; 
                if (i < argc):
                        clusterName = sys.argv[i]
                else:
                        argerr = "Missing argument for '" + arg + "' parameter"
                #endElse 
        elif (arg == "-zhelp"):
                help = 1
        elif (arg == "-install"):
                display = 0
        elif (arg == "-display"):
                display = 1
        else:
                argerr = "Invalid command line argument: "+arg
        #endElse 
        i += 1  #forNext
#endWhile  (#endFor)


if (help):
  print "      '%-25s  " % ( "required argument(s)"+"'" )     
  print "           '%-30s  <parameter>   Only in ND" % ( "-cluster"+"'" )          
  print "           '%-30s  <parameter>" % ( "-node"+"'" )          
  print "           '%-30s  <parameter>" % ( "-server"+"'" )          
  print "      '%-25s  " % ( "optional argument(s)"+"'" )          
  print "           '%-30s  <parameter>" % ( "-ports"+"'" )          
  for flag in flags :
     print "           '%-30s  <parameter>" % ( flag+"'" )          
  print "           '%-30s  " % ( "-zhelp" )          
  sys.exit()
#endIf 

if ( ("argerr" in locals().keys() or "argerr" in globals().keys())  ):
        print argerr
        sys.exit()
#endIf 

#
#  Figure out the type of cell (ND or Standalone Server) and build a list
#  of nodes on which to operate.
#
#  Check which type of cell...
#
isnd = AdminTask.isFederated()

if (isnd == 'true'):
    dmNodeName     = java.lang.System.getProperty ( "local.node" )

#------------------------------------------------------------------------------
# Validate all required fields
required = '-server, -node'
if (isnd == 'true') :
  required = required + ', -cluster'
#endif 
if ((isnd == 'true' and clusterName == "") or (serverName == "" or nodeName == "")) :
     print "Missing required field(s) " + required 
     sys.exit()
#endIf 

if ((isnd != 'true' and clusterName != "")) :
     print "Script Needs to be run on Deployment Manager "
     sys.exit()
#endIf 


    
#------------------------------------------------------------------------------
# Audit Arguments

print "--------------------------------------------------------------------------"


print " '-%-26s   <%-35s" % ("ports'", ports+">")
print " '-%-26s   <%-35s" % ("cluster'", clusterName+">")
print " '-%-26s   <%-35s" % ("node'", nodeName+">")
print " '-%-26s   <%-35s" % ("server'", serverName+">")
print " '-%-26s   <%-35s" % ("cell'", cellName+">")
print " '-%-26s   <%-35s" % ("ND'", isnd+">")

parameters = parameters.replace('-repositoryServerHeartbeat -1','-repositoryServerHeartbeat "OffLine"')

listParms = parameters.split(" -")

parameters = parameters.replace('-repositoryServerHeartbeat "OffLine"','-repositoryServerHeartbeat "-1"')

for parms in listParms:
   if parms != "":
     x= parms.split(" ")
     print " '-%-26s   <%-35s" % ( x[0]+"'", x[1]+">" )
 

if (display):
        print " '-display'        <DisplayOnly>      "
#endIf 

print "--------------------------------------------------------------------------"

if(ports !="") :
   assignPorts(ports, serverName, nodeName, cellName)
   updateEndpoints(cellName, nodeName, serverName)
   print "--------------------------------------------------------------------------"
#endIf

updateConfiguration(cellName, nodeName, serverName, clusterName, parameters)

# Use Environment Variables defined at the Cell. Replicated value fro DE is not correct
delscope ="/Node:"+nodeName+"/"
deleteProperty( 'DB2UNIVERSAL_JDBC_DRIVER_PATH' , delscope)
deleteProperty( 'DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH' , delscope)

if (display == 0):
  print "--------------------------------------------------------------------------"
  print "Saving Configuration"
  AdminConfig.save( )
  if (sync == 1 ):
      syncNodes()
  #endIf 
#endIf 

#Done

